pilas.ventana

Package pilas :: Module ventana |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.ventana

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10
    11  modo_depuracion = False
    12  eje_coordenadas = None
    13
    14 -def iniciar(ancho, alto, titulo):
    15      ventana = pilas.motor.crear_ventana(ancho, alto, titulo)
    16      return ventana
    17